#
# spec file for package grubby
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           grubby
Version:        20200210.99d10a3
Release:        bp153.1.1
Summary:        Command line tool for updating bootloader configs
License:        GPL-2.0-or-later
Group:          System/Base
URL:            https://github.com/rhboot/grubby
Source0:        %{name}-%{version}.tar.xz
# for make test / getopt:
BuildRequires:  grub2
BuildRequires:  pkgconfig
BuildRequires:  util-linux
BuildRequires:  pkgconfig(blkid)
BuildRequires:  pkgconfig(popt)
%ifarch s390 s390x
Requires:       s390-tools
%endif
%ifarch %{arm}
Requires:       u-boot-tools
%endif

%description
grubby is a command line tool for updating and displaying information about
the configuration files for the grub, lilo, elilo (ia64), yaboot (powerpc)
and zipl (s390) boot loaders. It is primarily designed to be used from scripts
which install new kernels and need to find information about the current boot
environment.

%prep
%autosetup -p1

%build
sed -i~ '
/^LDFLAGS/d
/^CFLAGS/d
/^grubby_LIBS/d
/^VERBOSE_TEST/d
' Makefile
diff -u "$_"~ "$_" && exit 1
CFLAGS="%{optflags} -std=gnu99 $(pkg-config --cflags blkid popt)"
LDFLAGS=
grubby_LIBS="$(pkg-config --libs blkid popt)"
%make_build CFLAGS="${CFLAGS}" LDFLAGS="${LDFLAGS}" grubby_LIBS="${grubby_LIBS}" VERSION='%{version}'

%check
%ifnarch aarch64
sed -i~ '
s@/vmlinuz-foo@/boot/vmlinuz-foo@
' test/results/add/g2-1.16
diff -u "$_"~ "$_" && exit 1
%make_build test VERBOSE_TEST="-b grub2"
%endif

%install
make install DESTDIR=%{buildroot} mandir="%{_mandir}"
# Remove installkernel as it is provided with mkinitrd package
rm %{buildroot}/sbin/installkernel
rm %{buildroot}/%{_mandir}/man8/installkernel.8

%files
%license COPYING
/sbin/new-kernel-pkg
/sbin/grubby
%{_mandir}/man8/*.8%{?ext_man}

%changelog
* Thu Apr 29 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Include in SLE-15 (bsc#1185283, jsc#ECO-3364, jsc#PM-2498)
* Thu Apr 29 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 20200210.99d10a3
  * Fix maybe-uninitialized warning
  * Fix stringop-overflow warning
- Fix incorrect package names in Requires
  * uboot-tools => u-boot-tools
  * s390-utils => s390-tools
- Disable tests on aarch64 again
- Run spec-cleaner
* Thu Sep  5 2019 olaf@aepfle.de
- Update to 20190801.fc69ba6
* Thu Apr 26 2018 guillaume.gardet@opensuse.org
- Remove %%arm specific files as they are not used
- Disable test for aarch64 since it is currently broken
* Tue Aug  8 2017 jengelh@inai.de
- Remove redundant %%clean section. Replace unusual RPM groups
  (yast categories) by more common ones.
* Mon Nov 30 2015 mlatimer@suse.com
- Update to version 8.40
* Thu Oct 10 2013 mlatimer@suse.com
- Update to version 8.29
- Delete suse-port.patch
* Thu Aug  8 2013 mlatimer@suse.com
- Initial version 8.25-1
- SUSE port - Added /boot/grub2/grub.cfg & /boot/grub2-efi/grub.cfg
  to grub2config file list (fate#315181)
